﻿; 7-ade archive expander for 7-Zip
; ©2016–2020 Daniel Beardsmore
; https://telcontar.net/Software/7-ade

#NoEnv
#NoTrayIcon
#SingleInstance Off

SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.

; Pretendoconstants
global k_APPNAME := "7-ade"
global k_APPVERSION := "1.1"
global k_COPYRIGHT := "©2016–2020 Daniel Beardsmore"
global k_WEBSITE := "https://telcontar.net/Software/7-ade/"

;@Ahk2Exe-SetName 7-ade
;@Ahk2Exe-SetDescription 7-ade Archive Expander
;@Ahk2Exe-SetVersion 1.1
;@Ahk2Exe-SetCopyright ©2016–2020 Daniel Beardsmore
;@Ahk2Exe-SetOrigFilename 7-ade.exe
;@Ahk2Exe-SetMainIcon 7-ade.ico

global k_EXIT_INITERROR := 1
global k_EXIT_INTERNALERROR := 2
global k_EXIT_INVOKEERROR := 3

;@Ahk2Exe-IgnoreBegin
#Warn
global g_debug := true
global k_REL := "Build\"
;@Ahk2Exe-IgnoreEnd
/*@Ahk2Exe-Keep
global g_debug := false
global k_REL := ""
*/

#Include <Decompressor>
#Include <Config>

global g_config := getConfig()
global g_7ZipPath := get7ZipPath()

if (g_config["debug"])
	g_debug := true

if (!g_7ZipPath)
{
	die(k_EXIT_INITERROR, "Unable to find 7-Zip on this computer.")
}

toExtract = %1%
if (toExtract && !FileExist(toExtract)) {
	die(k_EXIT_INVOKEERROR, "Specified archive """ . toExtract . """ does not exist.")
}

if (toExtract)
{
	runExtract(toExtract)
	ExitApp, 0
}
else
{
	Gui, +OwnDialogs
	Gui, Margin, 32, 16
	
	if A_IsCompiled
		Gui, Add, Picture, w128 h128, %A_ScriptFullPath%
	else
		Gui, Add, Picture, w128 h128, 7-ade.ico
	
	Gui, Font, s16
	Gui, Add, Text, ym, %k_APPNAME% Archive Expander
	Gui, Font, s10
	
	Gui, Add, Text, y+2, Version %k_APPVERSION%
	Gui, Add, Text, y+2, %k_COPYRIGHT%
	Gui, Add, Link, y+2, <a href="%k_WEBSITE%">%k_WEBSITE%</a>
	
	Gui, Add, Text,, Please open a file with this program to extract it.
	
	Gui, Add, Button, vviewDocs gshowDocs, View &readme
	GuiControl, Focus, viewDocs
	
	if (g_debug && g_config["demo file"] && FileExist(g_config["demo file"])) {
		Gui, Add, Button, gtestExtract, Test e&xtract
	}
	
	Gui, Show, Center, %k_APPNAME%
	return ; required to keep the window open
}


GuiClose:
	ExitApp
return


testExtract() {
	runExtract(A_ScriptDir . "\" . g_config["demo file"])
}


showDocs() {
	Run, %k_REL%Readme.html, , UseErrorLevel
	if (ErrorLevel != 0) {
		msgBox, 48, %k_APPNAME%, Could not open %k_REL%Readme.html
	}
}


dbg(message) {
	; Don’t pollute someone else's WinDbg session with our messages; only report debugging messages if
	; we’re intentionally running in debugging mode
	
	if (g_debug)
		OutputDebug, %message%
}


die(exitCode, message) {
	msgBox 16, %k_APPNAME%, %message% 
	ExitApp, %exitCode%
}